# BLACS

Part of the labscript suite, provides an interface to hardware used to control a buffered experiment. It manages a queue of shots to be run as well as providing manual control over devices between shots.

( 
[view on Bitbucket](https://bitbucket.org/labscript_suite/blacs)
)

   * For install instructions, see the [labscript suite install guide](https://bitbucket.org/labscript_suite/install-guide)
